@@ -212,7 +212,7 @@ sub scan {
             $e->{ $f }  ||= $connheader->{ $f } || '';
         }
         $e->{'agent'}   ||= __PACKAGE__->smtpagent;
-        $e->{'command'}   = shift @$commandset // 'CONN';
+        $e->{'command'}   = shift @$commandset || 'CONN';
         $e->{'diagnosis'} = Sisimai::String->sweep( $e->{'diagnosis'} );
 
         if( scalar @{ $mhead->{'received'} } ) {
